import { Message } from 'google-protobuf';
import { VMType, EvmTxReceipt } from './proto/loom_pb';
import { Address } from './address';
/**
 * Middleware handlers are expected to transform the input data and return the result.
 * Handlers should not modify the original input data in any way.
 */
export interface ITxMiddlewareHandler {
    Handle(txData: Readonly<Uint8Array>): Promise<Uint8Array>;
}
/**
 * Writes to & reads from a Loom DAppChain.
 */
export declare class Client {
    readonly chainId: string;
    readonly readUrl?: string;
    private _writeClient;
    private _readClient;
    txMiddleware: ITxMiddlewareHandler[];
    /**
     * Constructs a new client to read & write data from/to a Loom DAppChain.
     * @param chainId DAppChain identifier.
     * @param writeUrl Host & port to send txs, specified as "<protocol>://<host>:<port>".
     * @param readUrl Host & port of the DAppChain read/query interface.
     */
    constructor(chainId: string, writeUrl: string, readUrl?: string);
    disconnect(): void;
    /**
     * Commits a transaction to the DAppChain.
     *
     * Consider using Contract.callAsync() instead.
     *
     * @param tx Transaction to commit.
     * @returns Result (if any) returned by the tx handler in the contract that processed the tx.
     */
    commitTxAsync<T extends Message>(tx: T): Promise<Uint8Array | void>;
    /**
     * Queries the current state of a contract.
     *
     * Consider using Contract.staticCallAsync() instead.
     */
    queryAsync(contract: Address, query?: Uint8Array, vmType?: VMType): Promise<Uint8Array | void>;
    /**
     * Queries the receipt corresponding to a transaction hash
     *
     * @param txHash Transaction hash returned by call transaction.
     * @return EvmTxReceipt The corresponding transaction receipt.
     */
    getTxReceiptAsync(txHash: Uint8Array): Promise<EvmTxReceipt | null>;
    /**
     * Gets a nonce for the given public key.
     *
     * This should only be called by NonceTxMiddleware.
     *
     * @param key A hex encoded public key.
     * @return The nonce.
     */
    getNonceAsync(key: string): Promise<number>;
    /**
     * Tries to resolve a contract name to an address.
     *
     * @param contractName Name of a smart contract on a Loom DAppChain.
     * @returns Contract address, or null if a contract matching the given name wasn't found.
     */
    getContractAddressAsync(contractName: string): Promise<Address | null>;
}
